==> projen-0.46.3.tar.gz: package/lib/web/next.d.ts <==
import { Component } from '../component';
import { NodeProject, NodeProjectOptions } from '../javascript';
import { TypeScriptAppProject, TypeScriptProjectOptions } from '../typescript';
/**
 * @experimental
 */
export interface NextJsCommonProjectOptions {
    /**
     * (experimental) Assets directory.
     *
     * @default "public"
     * @experimental
     */
    readonly assetsdir?: string;
    /**
     * (experimental) Setup Tailwind CSS as a PostCSS plugin.
     *
     * @default true
     * @see https://tailwindcss.com/docs/installation
     * @experimental
     * @featured true
     */
    readonly tailwind?: boolean;
}
/**
 * @experimental
 */
export interface NextJsTypeScriptProjectOptions extends NextJsCommonProjectOptions, TypeScriptProjectOptions {
}
/**
 * @experimental
 */
export interface NextJsProjectOptions extends NextJsCommonProjectOptions, NodeProjectOptions {
    /**
     * (experimental) Typescript sources directory.
     *
     * @default "src"
     * @experimental
     */
    readonly srcdir?: string;
    /**
     * (experimental) Generate one-time sample in `pages/` and `public/` if there are no files there.
     *
     * @default true
     * @experimental
     */
    readonly sampleCode?: boolean;
}
/**
 * (experimental) Next.js project without TypeScript.
 *
 * @experimental
 * @pjid nextjs
 */
export declare class NextJsProject extends NodeProject {
    /**
     * (experimental) The directory in which source files reside.
     *
     * @experimental
     */
    readonly srcdir: string;
    /**
     * (experimental) The directory in which app assets reside.
     *
     * @experimental
     */
    readonly assetsdir: string;
    /**
     * (experimental) Setup Tailwind as a PostCSS plugin.
     *
     * @see https://tailwindcss.com/docs/installation
     * @experimental
     */
    readonly tailwind: boolean;
    /**
     * @experimental
     */
    constructor(options: NextJsProjectOptions);
}
/**
 * (experimental) Next.js project with TypeScript.
 *
 * @experimental
 * @pjid nextjs-ts
 */
export declare class NextJsTypeScriptProject extends TypeScriptAppProject {
    /**
     * (experimental) The directory in which source files reside.
     *
     * @experimental
     */
    readonly srcdir: string;
    /**
     * (experimental) The directory in which app assets reside.
     *
     * @experimental
     */
    readonly assetsdir: string;
    /**
     * (experimental) Setup Tailwind as a PostCSS plugin.
     *
     * @see https://tailwindcss.com/docs/installation
     * @experimental
     */
    readonly tailwind: boolean;
    /**
     * @experimental
     */
    constructor(options: NextJsTypeScriptProjectOptions);
}
/**
 * @experimental
 */
export interface NextComponentOptions {
    /**
     * (experimental) Whether to apply options specific for TypeScript Next.js projects.
     *
     * @default false
     * @experimental
     */
    readonly typescript?: boolean;
    /**
     * (experimental) Setup Tailwind as a PostCSS plugin.
     *
     * @default true
     * @see https://tailwindcss.com/docs/installation
     * @experimental
     */
    readonly tailwind?: boolean;
}
/**
 * @experimental
 */
export declare class NextComponent extends Component {
    private readonly typescript;
    private readonly tailwind;
    /**
     * @experimental
     */
    constructor(project: NodeProject, options: NextComponentOptions);
}

==> projen-0.98.4.tar.gz: package/lib/web/next.d.ts <==
import { Component } from "../component";
import { NodeProject, NodeProjectOptions } from "../javascript";
import { TypeScriptAppProject, TypeScriptProjectOptions } from "../typescript";
export interface NextJsCommonProjectOptions {
    /**
     * Assets directory
     *
     * @default "public"
     */
    readonly assetsdir?: string;
    /**
     * Setup Tailwind CSS as a PostCSS plugin.
     *
     * @see https://tailwindcss.com/docs/installation
     *
     * @default true
     * @featured
     */
    readonly tailwind?: boolean;
}
export interface NextJsTypeScriptProjectOptions extends NextJsCommonProjectOptions, TypeScriptProjectOptions {
}
export interface NextJsProjectOptions extends NextJsCommonProjectOptions, NodeProjectOptions {
    /**
     * Typescript sources directory.
     *
     * @default "src"
     */
    readonly srcdir?: string;
    /**
     * Generate one-time sample in `pages/` and `public/` if there are no files there.
     * @default true
     */
    readonly sampleCode?: boolean;
}
/**
 * Next.js project using JavaScript.
 *
 * @pjid nextjs
 */
export declare class NextJsProject extends NodeProject {
    /**
     * The directory in which source files reside.
     */
    readonly srcdir: string;
    /**
     * The directory in which app assets reside.
     */
    readonly assetsdir: string;
    /**
     * Setup Tailwind as a PostCSS plugin.
     *
     * @see https://tailwindcss.com/docs/installation
     */
    readonly tailwind: boolean;
    constructor(options: NextJsProjectOptions);
}
/**
 * Next.js project using TypeScript.
 *
 * @pjid nextjs-ts
 */
export declare class NextJsTypeScriptProject extends TypeScriptAppProject {
    /**
     * The directory in which source files reside.
     */
    readonly srcdir: string;
    /**
     * The directory in which app assets reside.
     */
    readonly assetsdir: string;
    /**
     * Setup Tailwind as a PostCSS plugin.
     *
     * @see https://tailwindcss.com/docs/installation
     */
    readonly tailwind: boolean;
    constructor(options: NextJsTypeScriptProjectOptions);
}
export interface NextComponentOptions {
    /**
     * Whether to apply options specific for TypeScript Next.js projects.
     *
     * @default false
     */
    readonly typescript?: boolean;
    /**
     * Setup Tailwind as a PostCSS plugin.
     *
     * @see https://tailwindcss.com/docs/installation
     *
     * @default true
     */
    readonly tailwind?: boolean;
}
export declare class NextComponent extends Component {
    private readonly typescript;
    private readonly tailwind;
    constructor(project: NodeProject, options: NextComponentOptions);
}
